@@ -25,6 +25,10 @@ def test_option_popsize():
         args = parse_args(["--popsize", "50A"])
         params = Params(args)
 
+    with pytest.raises(ValueError):
+        args = parse_args(["--popsize", "all=100"])
+        params = Params(args)
+
     with pytest.raises(ValueError):
         args = parse_args(["--popsize", "500", "A=300", "A=200"])
         params = Params(args)
@@ -386,7 +390,7 @@ def test_main_stop_if_error():
         main(["--jobs", "1", "--repeats", "100", "--stop-if", "st>1"])
 
 
-def test_symptomatic_transmissibility_model():
+def test_symptomatic_transmissibility_model(clear_log):
     with pytest.raises(Exception):
         main(
             [
@@ -429,7 +433,7 @@ def test_symptomatic_transmissibility_model():
     )
 
 
-def test_asymptomatic_transmissibility_model():
+def test_asymptomatic_transmissibility_model(clear_log):
     with pytest.raises(Exception):
         main(
             [
